@@ -85,6 +85,7 @@
       {"bisection_solver"         ,1, _BISECTION_SOLVER, _INT_SOLVER,T_NUMBER},
       {"blanc"         ,1, _WHITE, _INT_COLOR ,T_NUMBER},
       {"bleu"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
+      {"blue"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
       {"brent_solver"         ,1, _BRENT_SOLVER, _INT_SOLVER,T_NUMBER},
       {"by",1,0,0,T_BY},
       {"cap_flat_line"         ,1, _CAP_FLAT_LINE, _INT_COLOR ,T_NUMBER},
@@ -228,6 +229,7 @@
       {"golub_reinsch_decomp"         ,1, _GOLUB_REINSCH_DECOMP, _INT_SOLVER,T_NUMBER},
       {"golub_reinsch_mod_decomp"         ,1, _GOLUB_REINSCH_MOD_DECOMP, _INT_SOLVER,T_NUMBER},
       {"gomme"         ,1, _WHITE, /* was 49 */ _INT_COLOR ,T_NUMBER},
+      {"green"         ,1, _GREEN, _INT_COLOR ,T_NUMBER},
       {"groebner",1,_GROEBNER,_INT_MAPLELIB,T_MAPLELIB},
       {"hybrid_solver"         ,1, _HYBRID_SOLVER, _INT_SOLVER,T_NUMBER},
       {"hybridj_solver"         ,1, _HYBRIDJ_SOLVER, _INT_SOLVER,T_NUMBER},
@@ -354,6 +356,7 @@
       {"rational_det"         ,1, _RATIONAL_DET, _INT_SOLVER,T_NUMBER},
       {"rectangle_droit"         ,1, _RECTANGLE_DROIT, _INT_SOLVER,T_NUMBER},
       {"rectangle_gauche"         ,1, _RECTANGLE_GAUCHE, _INT_SOLVER,T_NUMBER},
+      {"red"         ,1, _RED, _INT_COLOR ,T_NUMBER},
       {"rempli"         ,1, _FILL_POLYGON , _INT_COLOR ,T_NUMBER},
       {"resolution"         ,1,_RESOLUTION , _INT_PLOT ,T_NUMBER},
       {"revlex"         ,1,_REVLEX_ORDER , _INT_GROEBNER ,T_NUMBER},
@@ -413,6 +416,7 @@
       {"with_f5"         ,1,_WITH_F5 , _INT_GROEBNER ,T_NUMBER},
       {"xstep"         ,1, _XSTEP , _INT_PLOT ,T_NUMBER},
       {"xtickmarks"         ,1,_XTICKMARKS , _INT_PLOT ,T_NUMBER},
+      {"yellow"         ,1, _YELLOW, _INT_COLOR ,T_NUMBER},
       {"ystep"         ,1, _YSTEP , _INT_PLOT ,T_NUMBER},
       {"zstep"         ,1, _ZSTEP , _INT_PLOT ,T_NUMBER},
       {"αστροειδές_σημείο"         ,1, _POINT_ETOILE , _INT_COLOR ,T_NUMBER},
